@@ -14,6 +14,7 @@ use constant {
     STATUS_NA      => 3,
     STATUS_SKIP    => 4,
     STATUS_PENDING => 5,
+    STATUS_TIMEOUT => 6,
 
     NOTIFIER_GITHUBSTATUSES => 'Ukigumo::Client::Notify::GitHubStatuses',
     NOTIFIER_IKACHAN        => 'Ukigumo::Client::Notify::Ikachan',
@@ -49,6 +50,8 @@ There is no reason to run the test cases.
 
 Tests are in process.
 
+=item STATUS_TIMEOUT
+
 =item NOTIFIER_GITHUBSTATUSES
 
 Notifier class name for GitHub Statuses.
